#
# spec file for package gnome-dictionary
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-dictionary
Version:        40.0
Release:        4.3
Summary:        Utility to look up words in dictionary sources
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://wiki.gnome.org/Apps/Dictionary
Source:         https://download.gnome.org/sources/gnome-dictionary/40/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM gnome-dictionary-fix-meson-061.patch -- Fix build with meson 0.61 and newer
Patch0:         gnome-dictionary-fix-meson-061.patch

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(glib-2.0) >= 2.39.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.16
Conflicts:      gnome-utils < 3.3.1
# libgdict is no longer a public library, and thus no external tool can make use of the data
# Merge the package back into the main package, obsoleting libgdict-data
Obsoletes:      libgdict-data < %{version}
Conflicts:      libgdict-1_0-6 < %{version}

%description
The Dictionary application enables you to search words and terms on a
dictionary source.

%lang_package

%prep
%autosetup -p1

%build
%meson \
        -D use_ipv6=true \
        -D build_man=true \
        %{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}/help
%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.Dictionary.desktop
%{_datadir}/dbus-1/services/org.gnome.Dictionary.service
%{_datadir}/gdict-1.0
%{_datadir}/glib-2.0/schemas/org.gnome.dictionary.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Dictionary.Devel.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Dictionary.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Dictionary-symbolic.svg
%{_datadir}/metainfo/org.gnome.Dictionary.appdata.xml
%{_mandir}/man1/%{name}.1%{?ext_man}

%files lang -f %{name}.lang

%changelog
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Thu Feb  3 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-dictionary-fix-meson-061.patch: Fix build with meson
  0.61 and newer.
- Replace update-desktop-files with desktop-file-utils
  BuildRequires, also add appstream-glib BuildRequires and check
  section and run meson_test macro during build. Validate appdata
  and desktop file.
- Remove unused lingering service files.
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Mar 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.0:
  + Dropped the app menu.
  + Updated the application help.
  + Removed non-working Spanish dict server.
  + Updated the application icon.
  + Updated the Flatpak sandbox and build.
  + Fixed compiler warnings when building with newer toolchains.
  + Fixed the sidebar sizing issue.
  + Updated translations.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Wed Apr 17 2019 olaf@aepfle.de
- Conflict with libgdict-1_0-6 because this pkg contained files which
  are now in the main pkg, namely $_datadir/gdict-1.0 (bsc#1132758)
* Mon Jul 23 2018 dimstar@opensuse.org
- Help translation-update-upstream finding the right gettext domain
  name: pass po %%{name} to the call.
* Thu Mar 22 2018 opensuse-packaging@opensuse.org
- Update to version 3.26.1+20180313.ac6d4c0:
  + Remove po/Makevars.
  + Flatpak: use meson from flatpak build definition.
  + Fix translations of the Name key.
  + Drop build-api wrapper for Continuous.
  + Updated translations.
- Switch to git-checkout via source services.
- Drop obsolete gnome-utils Conflicts and update-desktop-files
  BuildRequires and stop passing glib2_gsettings_schema_requires
  and suse_update_desktop_file macros.
- Use autosetup macro and pass explicit use_ipv6=true and
  build_man=true to meson, ensure we build the features we want.
- Update URL to correct home.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Oct  2 2017 luc14n0@linuxmail.org
- Update to version 3.26.1:
  + Menu for dictionary selection has too small size (bgo#777584).
  + Can't add dictionary sources (bgo#762589).
  + Updated translations.
* Tue Sep 12 2017 dimstar@opensuse.org
- Update to version 3.26.0:
  + Update the gnome-dictionary man page and install it
    (bgo#786319).
  + Ensure that desktop files and AppData metadata is valid.
  + Updated translations.
* Tue Aug 15 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + The GDict library is now private for GNOME Dictionary, and it
    is not installed any more.
  + The "Description" key for dictionary sources has been
    deprecated, and replaced with the "Comment" one, to allow for
    localisation with Gettext.
  + GNOME Dictionary does not depend on intltool for builds.
  + GNOME Dictionary switched to the Meson build system from
    Autotools.
  + Use natural_width for database popover (bgo#777584).
  + Fix typos in manual (bgo#766412).
  + Fix displaying the program name in the about dialog
    (bgo#784343).
  + Updated translations.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
- Drop intltool BuildRequires: no longer needed.
- Drop libgdata-1_0-10, typelib-1_0-GDict-1_0 and libgdict-data
  subpackage: the library is no longer public.
- Obsolete libgdict-data, as the files that were in this package
  have been merged into the main package.
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Move more UI into the XML template.
  + Fix the DatabaseChooserButton construction.
  + Remove unused app menu item.
  + Store the appropriate window size.
  + Bump up the dependency on GLib and GTK+.
  + Use Unicode in translatable strings.
  + Add Ctrl+Q keyboard accelerator quit shortcut.
  + Updated translations.
- Switch back to released tarball:
  + Drop _service handling.
  + Drop gnome-common BuildRequires and autogen.sh call.
* Mon Mar 13 2017 zaitor@opensuse.org
- Update to version 3.20.1+20170312.f3d61d5:
  + Add Flatpak manifest
  + Include the right header in GdictClientContext
  + Use gtk_show_uri_on_window() with newer GTK+
  + Use gtk_menu_popup_at_widget() with newer GTK+
  + Update translation.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
- Switch to source service and use latest upstream git. Following
  this: Add gnome-common BuildRequires and autogen call.
- Add gtk-doc BuildRequires: and pass --enable-gtk to configure,
  needed now that we use a git checkout.
- Add gobject-introspection-devel BuildRequires: New dependency.
- Split out new typelib sub package typelib-1_0-Gdict-1.0.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Updated translations.
* Sun Feb 14 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Application: Add a missing tag to the AppData file.
  + Updated translations.
* Mon Jan 25 2016 dimstar@opensuse.org
- Update to version 3.19.0:
  + Update the AppData file to spec version 0.7+.
  + Drop deprecated API from DefBox.
  + Bump required Gtk+ version.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.18.1:
  + Library:
  - Create new GdictDatabaseChooserButton widget.
  - Symbolic icons.
  + Application:
  - Fix spelling in "Creating XDG config directory" message.
  - Use GTK's automagic menu loading.
  - Symbolic icons.
  - Replace action area with header bar.
  - Replace deprecated GtkTable with GtkGrid.
  + Updated translations.
- Rename libgdict-1_0-9 subpackage to libgdict-1_0-10, following
  upstreams soname bump.
* Mon Sep 21 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Tue Aug 18 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Library:
  - Split lookup-start and lookup-end signals.
  - Improve GdictDatabaseChooser widget.
  - Add library initialize function.
  + Updated translations.
- Rename libgdict-1_0-8 subpackage to libgdict-1_0-9, following
  upstreams soname bump.
- Add libgdict-1_0-8 Obsoletes. We already obsolete libgdict-1_0-6.
* Mon Jul 20 2015 dimstar@opensuse.org
- Update to version 3.17.4:
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Remove Select All menu entry.
  + Remove Edit submenu.
  + Remove Close menu entry.
  + Make entries under File top-level menu entries.
  + Remove obsolete gdict_window_defbox_selection_changed.
  + Updated translations.
* Mon Jun 22 2015 dimstar@opensuse.org
- Own %%{_datadir}/appdata for openSUSE:42.
* Tue May 26 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Fix bgo#749131: Do not translate stack pages titles.
  + Remove Copy menu entry.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.17.1:
  + Pass the application pointer to the window constructor.
  + Drop homegrown app singleton.
  + Use widget templates to build GdictPrefDialog.
  + Rename the GdictPrefDialog UI definition.
  + Rename the menus UI definition file.
  + Use widget templates for GdictSourceDialog.
  + Updated translations.
* Tue May 12 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Application:
  - Remove compilation warnings.
  - Improve menu items sensitivity.
  + Library: Add GdictDefbox::selection-changed signal.
  + Updated translations.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Documentation: Fix paste keyboard shortcut.
  + Updated translations.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Implement GApplication::activate signal.
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Application:
  - Rename the AppData file to match the desktop name.
  - Drop slash for the 'Find' action.
  + Build system fixes.
  + Bugs fixed: bgo#745022.
  + Updated translations.
- Rename libgdict-1_0-6 subpackage to libgdict-1_0-8, following
  upstreams soname bump.
- Split out a new libgdict-data package, required by
  libgdata-1_0-8, in order to not have conflicts in the future.
- Obsolete libgdict-1_0-6 from the new -data package. Not exactly
  correct, but aids on upgrades. gnome-dictionary is the only
  consumer of this library.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Application:
  - Convert to new-style commandline option handling.
  - Make DBus-activatable.
  - bgo#528956: duplicated dictionary sources.
  + Library:
  - Fix emission of lookup-start.
  - Add GObject introspection support.
  + Updated translations.
* Mon Feb 16 2015 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Wed Nov 12 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Application: Use g_timeout_add_seconds() for multi-second
    timeouts.
  + Updated translations.
* Sun Oct 12 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + bgo#737626: expand sidebar.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Thu Sep 18 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Code fixes.
  + User documentation fixes.
  + Updated translations.
* Wed Oct  9 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Sidebar: Do not select unrealized menu items.
  + Fix bugzilla product in .desktop file.
  + Fix Ctrl+A and Ctrl+C in the search field.
  + Build system fixes.
  + Bugs fixed: bgo#706556.
  + Updated translations.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.0:
  + Updated translations.
* Sun Jul 21 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Re-written help in Mallard.
  + Updated translations.
- No longer pass --disable-scrollkeeper to configure: after the
  rewrite of the help in Mallard it is no longer used/known.
- Add fdupes BuildRequires and call fdupes in install section to
  link equal files, saving some space.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0:
  + Updated translations.
- Replace pkgconfig(gnome-doc-utils) BuildRequires with yelp-tools:
  even though not specified in NEWS, this release switched to the
  new documentation infrastructure.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Drop usage of deprecated methods
  + Use the new GMenu API
  + Updated translations.
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Use XDG configuration directories to store the dictionary data.
  + Updated translations.
* Tue Nov  1 2011 dimstar@opensuse.org
- Initial package, version 3.3.2:
  + First release after the split from gnome-utils.
